@@ -7,6 +7,8 @@ from numpy import exp
 
 
 def math_stream(formula, data, arg, get_data, XAS_streams=None, is_XAS=False, background=None, REIXSObj=None):
+    """Internal function to apply math operations as requested on input string
+    """
     # Split the user input string at all mathematical operations
     # Allow "( ) * / + -" as math
 
@@ -17,10 +19,11 @@ def math_stream(formula, data, arg, get_data, XAS_streams=None, is_XAS=False, ba
     # drop all empty strings from re.split
     quantity_str_dict = dict()
 
+    # Check all stripped strings individually and evaluate
     for i, string in enumerate(split_expr):
         if string != "":
             try:
-                float(string)
+                float(string) # Check if string is float
             except:
                 # Use math expressions to allow logs and exps
                 math_expressions = ['ln', 'log', 'exp']
@@ -29,6 +32,11 @@ def math_stream(formula, data, arg, get_data, XAS_streams=None, is_XAS=False, ba
                     pass
 
                 else:
+                    # Need to allow special case where negative numbers can be assigned in ET scan
+                    if string.endswith("ET["): # This will only be triggered if the arguments of [] are negative, otherwise the string will not be split
+                        string += '-' + split_expr[i+1] # Add the negative sign back in and add to current scan descriptor
+                        del split_expr[i+1] # Drop the extra element
+
                     # Assign generic "val{i}" key to string literal in compliance with
                     # python supported syntax for variables
                     quantity_str_dict[f"val{i}"] = string
